<?xml version='1.0' encoding='utf-8' ?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml"
	indent="yes"
	encoding="utf-8"
	doctype-system="ServiceHeaderPartMessageGuideline.dtd"/>

<!--Parameters used-->
<xsl:param name="SignalCode"/>

<!--Variables used-->

<!-- variable representing the toRole element -->
<xsl:variable name="ToRoleClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/fromRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<!-- variable representing the fromRole element -->
<xsl:variable name="FromRoleClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/toRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<!-- variable representing the PIP Indicator code element -->
<xsl:variable name="PipIndicatorCode" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/ActionIdentity/GlobalBusinessActionCode"/>

<!-- variable representing the PIP version identifier element -->
<xsl:variable name="PipVersion" select="/ServiceHeader/ProcessControl/ProcessIdentity/VersionIdentifier"/>

<!-- variable representing the Business Action instance id element -->
<xsl:variable name="BAInstanceId" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/ActionIdentity/InstanceIdentifier"/>

<!--Generate Acknowledgement XML-->
<xsl:template match="/">
<ServiceHeader>
	<ProcessControl>
		<xsl:copy-of select="ServiceHeader/ProcessControl/ProcessIdentity"></xsl:copy-of>
		<ServiceRoute>
			<fromService>
				<xsl:copy-of select="ServiceHeader/ProcessControl/ServiceRoute/toService/BusinessServiceDescription"/>
			</fromService>
			<toService>
				<xsl:copy-of select="ServiceHeader/ProcessControl/ServiceRoute/fromService/BusinessServiceDescription"/>
			</toService>
		</ServiceRoute>
		<TransactionControl>
			<xsl:copy-of select="ServiceHeader/ProcessControl/TransactionControl/AttemptCount"></xsl:copy-of>
			<PartnerRoleRoute>
				<fromRole>
					<PartnerRoleDescription>
						<GlobalPartnerRoleClassificationCode>
							<xsl:value-of select="$FromRoleClassificationCode"></xsl:value-of>
						</GlobalPartnerRoleClassificationCode>
					</PartnerRoleDescription>
				</fromRole>
				<toRole>
					<PartnerRoleDescription>
						<GlobalPartnerRoleClassificationCode>
							<xsl:value-of select="$ToRoleClassificationCode"></xsl:value-of>
						</GlobalPartnerRoleClassificationCode>
					</PartnerRoleDescription>
				</toRole>
			</PartnerRoleRoute>
			<xsl:copy-of select="ServiceHeader/ProcessControl/TransactionControl/TransactionIdentity"></xsl:copy-of>
			<SignalControl>
				<inResponseTo>
					<xsl:copy-of select="ServiceHeader/ProcessControl/TransactionControl/ActionControl/ActionIdentity"></xsl:copy-of>
				</inResponseTo>			
				<InstanceIdentifier><xsl:value-of select="concat($BAInstanceId, '_ack')"></xsl:value-of></InstanceIdentifier>
				<PartnerRoute>
					<fromPartner>
						<xsl:copy-of select="ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/toPartner/PartnerDescription"></xsl:copy-of>
					</fromPartner>
					<toPartner>
						<xsl:copy-of select="ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/fromPartner/PartnerDescription"></xsl:copy-of>
					</toPartner>
				</PartnerRoute>	
				<SignalIdentity>
					<GlobalBusinessSignalCode><xsl:value-of select="$SignalCode"/></GlobalBusinessSignalCode>
					<VersionIdentifier>1.1</VersionIdentifier>
				</SignalIdentity>
			</SignalControl>
		</TransactionControl>
	</ProcessControl>
</ServiceHeader>
</xsl:template>

</xsl:stylesheet>
<!-- Stylus Studio meta-information - (c)1998-2001 eXcelon Corp.
<metaInformation>
<scenarios/>
</metaInformation>
-->
