<?xml version='1.0' encoding='utf-8' ?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml"
	indent="yes"
	encoding="utf-8"
	doctype-system="ReceiptAcknowledgementExceptionMessageGuideline.dtd"/>

<!-- Parameters passed in from external environment-->
<xsl:param name="SenderId"/>
<xsl:param name="SenderGlobalSupplyChainCode"/>
<xsl:param name="ReceiverId"/>
<xsl:param name="ReceiverGlobalSupplyChainCode"/>
<xsl:param name="ProprietaryDocumentIdentifier"/>
<xsl:param name="Reason"/>
<xsl:param name="MessageDateTime"/>
<xsl:param name="ReceivedDocumentDateTime"/>
<xsl:param name="ContactName"/>
<xsl:param name="ContactPhone"/>
<xsl:param name="ContactEmail"/>

<!-- Values exctracted from the ServiceHeader-->
<xsl:variable name="fromPartnerRoleClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/toRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<xsl:variable name="fromPartnerClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/toPartner/PartnerDescription/GlobalPartnerClassificationCode"/>

<xsl:variable name="BAInstanceId" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/ActionIdentity/InstanceIdentifier"/>

<xsl:variable name="thisMessageIdentifier" select="concat($BAInstanceId, '_ack')"/>

<xsl:variable name="toPartnerRoleClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/fromRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<xsl:variable name="toPartnerClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/fromPartner/PartnerDescription/GlobalPartnerClassificationCode"/>

<!-- Build the Receipt exception payload -->
<xsl:template match="/">
<ReceiptAcknowledgementException>
	<fromRole>
		<PartnerRoleDescription>
			<ContactInformation>
				<contactName>
					<FreeFormText><xsl:value-of select="$ContactName"/></FreeFormText>
				</contactName>
				<EmailAddress><xsl:value-of select="$ContactEmail"/></EmailAddress>
				<telephoneNumber>
					<CommunicationsNumber><xsl:value-of select="$ContactPhone"/></CommunicationsNumber>
				</telephoneNumber>
			</ContactInformation>
			<GlobalPartnerRoleClassificationCode><xsl:value-of select="$fromPartnerRoleClassificationCode"/></GlobalPartnerRoleClassificationCode>
			<PartnerDescription>
				<BusinessDescription>
					<GlobalBusinessIdentifier><xsl:value-of select="$SenderId"/></GlobalBusinessIdentifier>
					<GlobalSupplyChainCode><xsl:value-of select="$SenderGlobalSupplyChainCode"/></GlobalSupplyChainCode>
				</BusinessDescription>
				<GlobalPartnerClassificationCode><xsl:value-of select="$fromPartnerClassificationCode"/></GlobalPartnerClassificationCode>
			</PartnerDescription>
		</PartnerRoleDescription>
	</fromRole>
	<reason>
		<FreeFormText><xsl:value-of select="$Reason"/></FreeFormText>
	</reason>
	<theMessageDatetime>
		<DateTimeStamp><xsl:value-of select="$MessageDateTime"/></DateTimeStamp>
	</theMessageDatetime>
	<theOffendingDocumentDateTime>
		<DateTimeStamp><xsl:value-of select="$ReceivedDocumentDateTime"/></DateTimeStamp>
	</theOffendingDocumentDateTime>
	<theOffendingDocumentIdentifier>
		<ProprietaryDocumentIdentifier><xsl:value-of select="$ProprietaryDocumentIdentifier"/></ProprietaryDocumentIdentifier>
	</theOffendingDocumentIdentifier>
	<thisMessageIdentifier>
		<ProprietaryMessageIdentifier><xsl:value-of select="$thisMessageIdentifier"/></ProprietaryMessageIdentifier>
	</thisMessageIdentifier>
	<toRole>
		<PartnerRoleDescription>
			<GlobalPartnerRoleClassificationCode><xsl:value-of select="$toPartnerRoleClassificationCode"></xsl:value-of></GlobalPartnerRoleClassificationCode>
			<PartnerDescription>
				<BusinessDescription>
					<GlobalBusinessIdentifier><xsl:value-of select="$ReceiverId"></xsl:value-of></GlobalBusinessIdentifier>
					<GlobalSupplyChainCode><xsl:value-of select="$ReceiverGlobalSupplyChainCode"></xsl:value-of></GlobalSupplyChainCode>
				</BusinessDescription>
				<GlobalPartnerClassificationCode><xsl:value-of select="$toPartnerClassificationCode"></xsl:value-of></GlobalPartnerClassificationCode>
			</PartnerDescription>
		</PartnerRoleDescription>
	</toRole>
</ReceiptAcknowledgementException>
</xsl:template>

</xsl:stylesheet>