<?xml version='1.0' encoding='utf-8' ?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml"
	indent="yes"
	encoding="utf-8"
	doctype-system="ReceiptAcknowledgementMessageGuideline.dtd"/>

<!-- Parameters passed in from external environment-->
<xsl:param name='SenderId'/>
<xsl:param name='SenderGlobalSupplyChainCode'/>
<xsl:param name='ReceiverId'/>
<xsl:param name='ReceiverGlobalSupplyChainCode'/>
<xsl:param name="ProprietaryDocumentIdentifier"/>
<xsl:param name="Digest"/>
<xsl:param name="DigestAlgorithm"/>
<xsl:param name="MessageDateTime"/>
<xsl:param name="ReceivedDocumentDateTime"/>
<xsl:param name="ContactName"/>
<xsl:param name="ContactPhone"/>
<xsl:param name="ContactEmail"/>

<!-- Local variables extracted from service header-->
<xsl:variable name="fromClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/toRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<xsl:variable name="toClassificationCode" select="/ServiceHeader/ProcessControl/TransactionControl/PartnerRoleRoute/fromRole/PartnerRoleDescription/GlobalPartnerRoleClassificationCode"/>

<xsl:variable name="fromPartnerFunction" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/toPartner/PartnerDescription/GlobalPartnerClassificationCode"/>

<xsl:variable name="toPartnerFunction" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/PartnerRoute/fromPartner/PartnerDescription/GlobalPartnerClassificationCode"/>

<xsl:variable name="BAInstanceId" select="/ServiceHeader/ProcessControl/TransactionControl/ActionControl/ActionIdentity/InstanceIdentifier"/>

<xsl:template match="/">
<ReceiptAcknowledgement>
	<fromRole>
		<PartnerRoleDescription>
			<ContactInformation>
				<contactName>
					<FreeFormText><xsl:value-of select="$ContactName"/></FreeFormText>
				</contactName>
				<EmailAddress><xsl:value-of select="$ContactEmail"/></EmailAddress>
				<telephoneNumber>
					<CommunicationsNumber><xsl:value-of select="$ContactPhone"/></CommunicationsNumber>
				</telephoneNumber>
			</ContactInformation>
			<GlobalPartnerRoleClassificationCode><xsl:value-of select="$fromClassificationCode"></xsl:value-of></GlobalPartnerRoleClassificationCode>
			<PartnerDescription>
				<BusinessDescription>
					<GlobalBusinessIdentifier><xsl:value-of select="$SenderId"></xsl:value-of></GlobalBusinessIdentifier>
					<GlobalSupplyChainCode><xsl:value-of select="$SenderGlobalSupplyChainCode"></xsl:value-of></GlobalSupplyChainCode>
				</BusinessDescription>
				<GlobalPartnerClassificationCode><xsl:value-of select="$fromPartnerFunction"></xsl:value-of></GlobalPartnerClassificationCode>
			</PartnerDescription>
		</PartnerRoleDescription>
	</fromRole>
	<xsl:choose>
		<xsl:when test="$Digest!=''">
			<NonRepudiationInformation>
				<GlobalDigestAlgorithmCode><xsl:value-of select="$DigestAlgorithm"></xsl:value-of></GlobalDigestAlgorithmCode>
				<OriginalMessageDigest><xsl:value-of select="$Digest"></xsl:value-of></OriginalMessageDigest>
			</NonRepudiationInformation>
		</xsl:when>
	</xsl:choose>
	<receivedDocumentDateTime>
		<DateTimeStamp><xsl:value-of select="$ReceivedDocumentDateTime"/></DateTimeStamp>
	</receivedDocumentDateTime>
	<receivedDocumentIdentifier>
		<ProprietaryDocumentIdentifier><xsl:value-of select="$ProprietaryDocumentIdentifier"></xsl:value-of></ProprietaryDocumentIdentifier>
	</receivedDocumentIdentifier>
	<thisMessageDateTime>
		<DateTimeStamp><xsl:value-of select="$MessageDateTime"/></DateTimeStamp>
	</thisMessageDateTime>
	<thisMessageIdentifier>
		<ProprietaryMessageIdentifier><xsl:value-of select="concat($BAInstanceId, '_ack')"></xsl:value-of></ProprietaryMessageIdentifier>
	</thisMessageIdentifier>
	<toRole>
		<PartnerRoleDescription>
			<GlobalPartnerRoleClassificationCode><xsl:value-of select="$toClassificationCode"></xsl:value-of></GlobalPartnerRoleClassificationCode>
			<PartnerDescription>
				<BusinessDescription>
					<GlobalBusinessIdentifier><xsl:value-of select="$ReceiverId"></xsl:value-of></GlobalBusinessIdentifier>
					<GlobalSupplyChainCode><xsl:value-of select="$ReceiverGlobalSupplyChainCode"></xsl:value-of></GlobalSupplyChainCode>
				</BusinessDescription>
				<GlobalPartnerClassificationCode><xsl:value-of select="$toPartnerFunction"></xsl:value-of></GlobalPartnerClassificationCode>
			</PartnerDescription>
		</PartnerRoleDescription>
	</toRole>
</ReceiptAcknowledgement>
</xsl:template>

</xsl:stylesheet>
<!-- Stylus Studio meta-information - (c)1998-2001 eXcelon Corp.
<metaInformation>
<scenarios/>
</metaInformation>
-->
