<?xml version='1.0' encoding='utf-8' ?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:mcd="http://www.cyclonecommerce.com/Schemas/2001/08/mcd">

<xsl:output indent="no" method="xml"
	encoding="utf-8"
	cdata-section-elements="mcd:Body"/>

<!-- Parameters -->
<xsl:param name="MaxRetry"/>
<xsl:param name="RetryInterval"/>
<xsl:param name="GlobalProcessCode"/>
<xsl:param name="DefaultSenderService"/>
<xsl:param name="DefaultReceiverService"/>
<xsl:param name="DefaultSenderRole"/>
<xsl:param name="DefaultReceiverRole"/>
<xsl:param name="DefaultSenderFunction"/>
<xsl:param name="DefaultReceiverFunction"/>
<xsl:param name="DefaultActivityName"/>
<xsl:param name="DefaultSecureTransport"/>
<xsl:param name="MessageDateTime"/>

<!-- Variables -->
<xsl:variable name="standard" select="/MessageControlDocument/PackagingProtocol/Standard"/>
<xsl:variable name="rnifVersion" select="/MessageControlDocument/PackagingProtocol/Version"/>
<xsl:variable name="sessionId" select="/MessageControlDocument/TransportInfo/SessionID"/>
<xsl:variable name="statusType" select="/MessageControlDocument/StatusInfo/StatusType"/>
<xsl:variable name="exceptionType" select="/MessageControlDocument/StatusInfo/ExceptionInfo/ExceptionType"/>
<xsl:variable name="digestValue" select="/MessageControlDocument/StatusInfo/DigestInfo/DigestValue"/>
<xsl:variable name="trackingId" select="/MessageControlDocument/TransportInfo/MessageTrackingID"/>

<!-- Build the StatusInfo ExceptionInfo element -->
<xsl:template name="insertStatusInfoDescription">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/StatusInfo/OriginalActionInfo/Description!=''">
			<mcd:Description><xsl:value-of select="/MessageControlDocument/StatusInfo/OriginalActionInfo/Description"/></mcd:Description>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Build the mcd:ExceptionInfo element -->
<xsl:template name="insertExceptionInfo">
	<xsl:choose>
		<xsl:when test="$exceptionType!=''">
			<mcd:ExceptionInfo type="{$exceptionType}">
				<mcd:ErrorDescription><xsl:value-of select="/MessageControlDocument/StatusInfo/ExceptionInfo/ErrorDescription"/></mcd:ErrorDescription>
				<mcd:ErrorClassification><xsl:value-of select="/MessageControlDocument/StatusInfo/ExceptionInfo/ErrorClassification"/></mcd:ErrorClassification>
			</mcd:ExceptionInfo>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Build the mcd:DigestInfo element -->
<xsl:template name="insertDigestInfo">
	<xsl:choose>
		<xsl:when test="$digestValue!=''">
			<mcd:DigestInfo>
				<mcd:DigestValue><xsl:value-of select="$digestValue"/></mcd:DigestValue>
				<mcd:DigestAlgorithm><xsl:value-of select="/MessageControlDocument/StatusInfo/DigestInfo/DigestAlgorithm"/></mcd:DigestAlgorithm>
			</mcd:DigestInfo>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Build the mcd:StatusInfo element -->
<xsl:template name="insertStatusInfo">
	<xsl:choose>
		<xsl:when test="$statusType!=''">
			<mcd:StatusInfo type="{$statusType}">
				<xsl:call-template name="insertStatusInfoDescription"/>
				<xsl:call-template name="insertExceptionInfo"/>
				<xsl:call-template name="insertDigestInfo"/>
			</mcd:StatusInfo>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Builds the rosettanet:Preamble element -->
<xsl:template name="insertPreamble1_1Body"><![CDATA[<?xml version="1.0"?>
<!DOCTYPE Preamble SYSTEM "PreamblePartMessageGuideline.dtd">
<!-- Created by Cyclone Commerce - Trading in the eDimension

     Cyclone Commerce Inc.
     Scottsdale, Arizona, USA.
     T480 627-1800 F480 627-1801
     www.cyclonecommerce.com
-->
<Preamble>
	<DateTimeStamp>]]><xsl:value-of select="$MessageDateTime"/><![CDATA[</DateTimeStamp>
	<GlobalAdministeringAuthorityCode>]]><xsl:value-of select="$standard"/><![CDATA[</GlobalAdministeringAuthorityCode>
	<GlobalUsageCode>]]><xsl:value-of select="/MessageControlDocument/PackagingProtocol/Usage"/><![CDATA[</GlobalUsageCode>
	<VersionIdentifier>1.1</VersionIdentifier>
</Preamble>]]>
</xsl:template>

<!-- Builds the rosettanet:Preamble element -->
<xsl:template name="insertPreamble2_0Body"><![CDATA[<?xml version='1.0'?>
<!DOCTYPE Preamble SYSTEM "Preamble_MS_B02_00.dtd" >
<!-- Created by Cyclone Commerce - Trading in the eDimension

     Cyclone Commerce Inc.
     Scottsdale, Arizona, USA.
     T480 627-1800 F480 627-1801
     www.cyclonecommerce.com
-->
<Preamble>
  <standardName>
    <GlobalAdministeringAuthorityCode>]]><xsl:value-of select="$standard"/><![CDATA[</GlobalAdministeringAuthorityCode>
  </standardName>
  <standardVersion>
  <VersionIdentifier>2.0</VersionIdentifier>
  </standardVersion>
</Preamble>]]>
</xsl:template>

<xsl:template name="insertPreamble">
	<mcd:MessageContentInfo>
		<mcd:MIMEContentId><xsl:value-of select="concat($trackingId, '_preamble')"/></mcd:MIMEContentId>
		<mcd:MIMEContentType>application/xml</mcd:MIMEContentType>
		<mcd:Description>This is the preamble portion of the message</mcd:Description>
		<mcd:Body bodyEncoding="7-bit">
			<xsl:choose>
				<xsl:when test="$rnifVersion='1.1'">
					<xsl:call-template name="insertPreamble1_1Body"/>
				</xsl:when>
				<xsl:when test="$rnifVersion='2.0'">
					<xsl:call-template name="insertPreamble2_0Body"/>
				</xsl:when>
			</xsl:choose>
		</mcd:Body>
		</mcd:MessageContentInfo>
</xsl:template>

<!-- Inserts the IsSecureTransportRequired element -->
<xsl:template name="insertIsSecureTransportRequired">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/TransportInfo/IsSecureTransportRequired!=''">
			<xsl:value-of select="/MessageControlDocument/TransportInfo/IsSecureTransportRequired"/>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$DefaultSecureTransport"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Insert the Delivery Header -->
<xsl:template name="insertDeliveryHeader">
	<xsl:choose>
		<xsl:when test="$rnifVersion='2.0'">
			<mcd:MessageContentInfo>
			<mcd:MIMEContentId><xsl:value-of select="concat($trackingId, '_deliveryheader')"/></mcd:MIMEContentId>
			<mcd:MIMEContentType>application/xml</mcd:MIMEContentType>
			<mcd:Description>This is the delivery header portion of the message</mcd:Description>
			<mcd:Body bodyEncoding="7-bit"><![CDATA[<?xml version='1.0'?>
<!DOCTYPE DeliveryHeader SYSTEM "DeliveryHeader_MS_B02_00.dtd" >
<DeliveryHeader>
  <isSecureTransportRequired>
    <AffirmationIndicator>]]><xsl:call-template name="insertIsSecureTransportRequired"/><![CDATA[</AffirmationIndicator>
  </isSecureTransportRequired>
  <messageDateTime>
    <DateTimeStamp>]]><xsl:value-of select="$MessageDateTime"/><![CDATA[</DateTimeStamp>
  </messageDateTime>
  <messageReceiverIdentification>
    <PartnerIdentification>
      <domain>
        <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/Domain"/><![CDATA[</FreeFormText>
      </domain>
      <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
      <locationID>
        <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/LocationID"/><![CDATA[</FreeFormText>
      </locationID>
    </PartnerIdentification>
  </messageReceiverIdentification>
  <messageSenderIdentification>
    <PartnerIdentification>
      <domain>
        <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/Domain"/><![CDATA[</FreeFormText>
      </domain>
      <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
      <locationID>
        <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/LocationID"/><![CDATA[</FreeFormText>
      </locationID>
    </PartnerIdentification>
  </messageSenderIdentification>
  <messageTrackingID>
    <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/TransportInfo/MessageTrackingID"/><![CDATA[</InstanceIdentifier>
  </messageTrackingID>
</DeliveryHeader>
]]></mcd:Body>
			</mcd:MessageContentInfo>					
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Determines the sender service to use -->
<xsl:template name="insertSenderService">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerBusinessServiceCode!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerBusinessServiceCode"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultSenderService"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the receiver service to use -->
<xsl:template name="insertReceiverService">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerBusinessServiceCode!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerBusinessServiceCode"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultReceiverService"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Inserts the attempt count -->
<xsl:template name="insertAttemptCount">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/TransactionInfo/AttemptCount!=''">
			<xsl:value-of select="/MessageControlDocument/TransactionInfo/AttemptCount"/>
		</xsl:when>
		<xsl:otherwise>	0</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the sender role to use -->
<xsl:template name="insertSenderRole">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerRole!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerRole"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultSenderRole"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the receiver role to use -->
<xsl:template name="insertReceiverRole">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerRole!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerRole"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultReceiverRole"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the global document function code -->
<xsl:template name="insertGlobalDocumentFunctionCode">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/BusinessActionInfo/DocumentFunction!=''">
			<xsl:value-of select="/MessageControlDocument/BusinessActionInfo/DocumentFunction"/>
		</xsl:when>
		<xsl:otherwise>Request</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the sender function code -->
<xsl:template name="insertSenderFunction">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerFunction!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerFunction"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultSenderFunction"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Determines the receiver function code -->
<xsl:template name="insertReceiverFunction">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerFunction!=''">
			<xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerFunction"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$DefaultReceiverFunction"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Insert the InResponseTo description element -->
<xsl:template name="insertInResponseToDescription">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/Description!=''">
            <![CDATA[<description>
              <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/Description"/><![CDATA[</FreeFormText>
            </description>]]>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Determines the InResponseTo element -->
<xsl:template name="insertInResponseTo">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/BusinessActionCode!=''">
        <![CDATA[<inResponseTo>
          <ActionIdentity>]]><xsl:call-template name="insertInResponseToDescription"/><![CDATA[            <GlobalBusinessActionCode>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/BusinessActionCode"/><![CDATA[</GlobalBusinessActionCode>
            <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/InstanceID"/><![CDATA[</InstanceIdentifier>
            <VersionIdentifier>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/OriginalActionInfo/Version"/><![CDATA[</VersionIdentifier>
          </ActionIdentity>
        </inResponseTo>]]>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<!-- Insert the TimeDuration element -->
<xsl:template name="insertTimeDuration">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/BusinessActionInfo/TimeToAcknowledgeReceipt!=''">
			<xsl:value-of select="/MessageControlDocument/BusinessActionInfo/TimeToAcknowledgeReceipt"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$RetryInterval"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Builds the RNIF 1.1 ServiceHeader body -->
<xsl:template name="insert1_1ServiceHeaderBody"><![CDATA[<?xml version='1.0'?>
<!DOCTYPE ServiceHeader SYSTEM "ServiceHeaderPartMessageGuideline.dtd" >
<ServiceHeader>
  <ProcessControl>
    <ProcessIdentity>
      <description>
         <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/Description"/><![CDATA[</FreeFormText>
      </description>
      <GlobalProcessCode>]]><xsl:value-of select="$GlobalProcessCode"/><![CDATA[</GlobalProcessCode>
      <GlobalProcessIndicatorCode>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPIndicatorCode"/><![CDATA[</GlobalProcessIndicatorCode>
      <initiatingPartner>
        <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/InitiatorInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
      </initiatingPartner>
      <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPInstanceID"/><![CDATA[</InstanceIdentifier>
      <VersionIdentifier>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPVersion"/><![CDATA[</VersionIdentifier>
    </ProcessIdentity>
    <ServiceRoute>
      <fromService>
        <BusinessServiceDescription>
          <GlobalBusinessServiceCode>]]><xsl:call-template name="insertSenderService"/><![CDATA[</GlobalBusinessServiceCode>
        </BusinessServiceDescription>
      </fromService>
      <toService>
        <BusinessServiceDescription>
          <GlobalBusinessServiceCode>]]><xsl:call-template name="insertReceiverService"/><![CDATA[</GlobalBusinessServiceCode>
        </BusinessServiceDescription>
      </toService>
    </ServiceRoute>
    <TransactionControl>
      <AttemptCount>]]><xsl:call-template name="insertAttemptCount"/><![CDATA[</AttemptCount>
      <PartnerRoleRoute>
        <fromRole>
          <PartnerRoleDescription>
            <GlobalPartnerRoleClassificationCode>]]><xsl:call-template name="insertSenderRole"/><![CDATA[</GlobalPartnerRoleClassificationCode>
          </PartnerRoleDescription>
        </fromRole>
        <toRole>
          <PartnerRoleDescription>
            <GlobalPartnerRoleClassificationCode>]]><xsl:call-template name="insertReceiverRole"/><![CDATA[</GlobalPartnerRoleClassificationCode>
          </PartnerRoleDescription>
        </toRole>
      </PartnerRoleRoute>
      <TransactionIdentity>
	     <description>
	        <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/TransactionInfo/Description"/><![CDATA[</FreeFormText>
	     </description>
        <GlobalTransactionCode>]]><xsl:call-template name="insertActivityName"/><![CDATA[</GlobalTransactionCode>
        <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/TransactionInfo/InstanceID"/><![CDATA[</InstanceIdentifier>
      </TransactionIdentity>
      <ActionControl>
        <ActionIdentity>
	       <description>
	          <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/Description"/><![CDATA[</FreeFormText>
	       </description>
          <GlobalBusinessActionCode>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/BusinessActionCode"/><![CDATA[</GlobalBusinessActionCode>
          <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/InstanceID"/><![CDATA[</InstanceIdentifier>
          <VersionIdentifier>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/Version"/><![CDATA[</VersionIdentifier>
        </ActionIdentity>
        <GlobalDocumentFunctionCode>]]><xsl:call-template name="insertGlobalDocumentFunctionCode"/><![CDATA[</GlobalDocumentFunctionCode>]]><xsl:call-template name="insertInResponseTo"/><![CDATA[
        <PartnerRoute>
          <fromPartner>
            <PartnerDescription>
              <BusinessDescription>
                <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
              </BusinessDescription>
              <GlobalPartnerClassificationCode>]]><xsl:call-template name="insertSenderFunction"/><![CDATA[</GlobalPartnerClassificationCode>
            </PartnerDescription>
          </fromPartner>
          <toPartner>
            <PartnerDescription>
              <BusinessDescription>
                <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
              </BusinessDescription>
              <GlobalPartnerClassificationCode>]]><xsl:call-template name="insertReceiverFunction"/><![CDATA[</GlobalPartnerClassificationCode>
            </PartnerDescription>
          </toPartner>
        </PartnerRoute>
        <PerformanceControlRequest>
          <timeToAcknowledgeReceipt>
            <TimeDuration>]]><xsl:call-template name="insertTimeDuration"/><![CDATA[</TimeDuration>
          </timeToAcknowledgeReceipt>
        </PerformanceControlRequest>
      </ActionControl>
    </TransactionControl>
  </ProcessControl>
</ServiceHeader>
]]>
</xsl:template>

<!-- Insert the activity identifier-->
<xsl:template name="insertActivityName">
	<xsl:choose>
		<xsl:when test="/MessageControlDocument/BusinessActionInfo/BusinessActivityName!=''">
			<xsl:value-of select="/MessageControlDocument/BusinessActionInfo/BusinessActivityName"/>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$DefaultActivityName"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Insert any attachments -->
<xsl:template name="insertServiceHeaderAttachments">
	<xsl:for-each select="/MessageControlDocument/ManifestInfo/AttachmentInfo">
		<Attachment>
			<description>
			   <FreeFormText><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/Description"/></FreeFormText>
			</description>
			<GlobalMimeTypeQualifierCode><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/MimeContentType"/></GlobalMimeTypeQualifierCode>
			<UniversalResourceIdentifier><xsl:value-of select="concat('cid:', /MessageControlDocument/ManifestInfo/AttachmentInfo/MIMEContentID)"/></UniversalResourceIdentifier>
		</Attachment>
	</xsl:for-each>
</xsl:template>

<!-- Builds the message standard -->
<xsl:template name="insertMessageStandard">
  <xsl:choose>
   <xsl:when test="/MessageControlDocument/BusinessActionInfo/MessageStandard!=''">          
      <messageStandard><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/MessageStandard"/></messageStandard>
   </xsl:when>
  </xsl:choose>
</xsl:template>

<!-- Builds the message standard version -->
<xsl:template name="insertStandardVersion">
  <xsl:choose>
   <xsl:when test="/MessageControlDocument/BusinessActionInfo/MessageStandardVersion!=''">          
      <standardVersion>
         <VersionIdentifier><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/MessageStandardVersion"/></VersionIdentifier>
      </standardVersion>
   </xsl:when>
  </xsl:choose>
</xsl:template>

<!-- Builds the 2.0 Service Header body -->
<xsl:template name="insert2_0ServiceHeaderBody"><![CDATA[<?xml version='1.0'?>
<!DOCTYPE ServiceHeader SYSTEM "ServiceHeader_MS_B02_00.dtd" >
<ServiceHeader>
  <ProcessControl>
    <ActivityControl>
      <BusinessActivityIdentifier>]]><xsl:call-template name="insertActivityName"/><![CDATA[</BusinessActivityIdentifier>
      <MessageControl>
        <fromRole>
          <GlobalPartnerRoleClassificationCode>]]><xsl:call-template name="insertSenderRole"/><![CDATA[</GlobalPartnerRoleClassificationCode>
        </fromRole>
        <fromService>
          <GlobalBusinessServiceCode>]]><xsl:call-template name="insertSenderService"/><![CDATA[</GlobalBusinessServiceCode>
        </fromService>
        <Manifest>
          ]]><xsl:call-template name="insertServiceHeaderAttachments"/><![CDATA[
          <numberOfAttachments>
            <CountableAmount>]]><xsl:value-of select="count(/MessageControlDocument/ManifestInfo/AttachmentInfo)"/><![CDATA[</CountableAmount>
          </numberOfAttachments>
          <ServiceContentControl>
            <ActionIdentity>
              <GlobalBusinessActionCode>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/BusinessActionCode"/><![CDATA[</GlobalBusinessActionCode>]]>
              <xsl:call-template name="insertMessageStandard"/>
              <xsl:call-template name="insertStandardVersion"/><![CDATA[
              <VersionIdentifier>]]><xsl:value-of select="/MessageControlDocument/BusinessActionInfo/Version"/><![CDATA[</VersionIdentifier>
            </ActionIdentity>
          </ServiceContentControl>
        </Manifest>
        <toRole>
          <GlobalPartnerRoleClassificationCode>]]><xsl:call-template name="insertReceiverRole"/><![CDATA[</GlobalPartnerRoleClassificationCode>
        </toRole>
        <toService>
          <GlobalBusinessServiceCode>]]><xsl:call-template name="insertReceiverService"/><![CDATA[</GlobalBusinessServiceCode>
        </toService>
      </MessageControl>
    </ActivityControl>
    <GlobalUsageCode>]]><xsl:value-of select="/MessageControlDocument/PackagingProtocol/Usage"/><![CDATA[</GlobalUsageCode>
    <partnerDefinedPIPPayloadBindingId>
       <ProprietaryReferenceIdentifier>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPPayloadBindingID"/><![CDATA[</ProprietaryReferenceIdentifier>
    </partnerDefinedPIPPayloadBindingId>
    <pipCode>
      <GlobalProcessCode>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPIndicatorCode"/><![CDATA[</GlobalProcessCode>
    </pipCode>
    <pipInstanceId>
      <InstanceIdentifier>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPInstanceID"/><![CDATA[</InstanceIdentifier>
    </pipInstanceId>
    <pipVersion>
      <VersionIdentifier>]]><xsl:value-of select="/MessageControlDocument/ProcessInfo/PIPVersion"/><![CDATA[</VersionIdentifier>
    </pipVersion>
    <KnownInitiatingPartner>
      <PartnerIdentification>
        <domain>
          <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/InitiatorInfo/Domain"/><![CDATA[</FreeFormText>
        </domain>
        <GlobalBusinessIdentifier>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/InitiatorInfo/PartnerID"/><![CDATA[</GlobalBusinessIdentifier>
        <locationID>
          <FreeFormText>]]><xsl:value-of select="/MessageControlDocument/PartnerInfo/InitiatorInfo/LocationID"/><![CDATA[</FreeFormText>
        </locationID>
      </PartnerIdentification>
    </KnownInitiatingPartner>
  </ProcessControl>
</ServiceHeader>]]>
</xsl:template>

<!-- Builds the RNIF ServiceHeader element -->
<xsl:template name="insertServiceHeader">
	<mcd:MessageContentInfo>
		<mcd:MIMEContentId><xsl:value-of select="concat($trackingId, '_serviceheader')"/></mcd:MIMEContentId>
		<mcd:MIMEContentType>application/xml</mcd:MIMEContentType>
		<mcd:Description>This is the service header portion of the message</mcd:Description>
		<mcd:Body bodyEncoding="7-bit">
			<xsl:choose>
				<xsl:when test="$rnifVersion='1.1'">
					<xsl:call-template name="insert1_1ServiceHeaderBody"/>
				</xsl:when>
				<xsl:when test="$rnifVersion='2.0'">
					<xsl:call-template name="insert2_0ServiceHeaderBody"/>
				</xsl:when>
			</xsl:choose>
		</mcd:Body>
	</mcd:MessageContentInfo>
</xsl:template>

<!-- Builds the RNIF ServiceContent element -->
<xsl:template name="insertServiceContent">
	<mcd:MessageContentInfo>
		<mcd:MIMEContentId><xsl:value-of select="concat($trackingId, '_servicecontent')"/></mcd:MIMEContentId>
		<mcd:MIMEContentType>application/xml</mcd:MIMEContentType>
		<mcd:Description>This is the service content portion of the message</mcd:Description>
		<mcd:Body bodyEncoding="7-bit"><![CDATA[]]><xsl:value-of select="/MessageControlDocument/ManifestInfo/ServiceContentInfo/Body"/><![CDATA[]]></mcd:Body>
	</mcd:MessageContentInfo>
</xsl:template>

<!-- inserts the mcd:ManifestInfo element -->
<xsl:template name="insertManifestInfo">
	<mcd:ManifestInfo>
		<xsl:call-template name="insertPreamble"/>
		<xsl:call-template name="insertDeliveryHeader"/>
		<xsl:call-template name="insertServiceHeader"/>
		<xsl:call-template name="insertServiceContent"/>
		<xsl:call-template name="insertAttachments"/>
	</mcd:ManifestInfo>
</xsl:template>

<xsl:template match="/">
	<mcd:MessageControlDocument xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="2.0" xsi:schemaLocation="http://www.cyclonecommerce.com/Schemas/2001/08/mcd http://www.cyclonecommerce.com/Schemas/2001/08/MCD_v2_0.xsd">
		<mcd:PackagingProtocol>
			<mcd:Standard><xsl:value-of select="$standard"/></mcd:Standard>
			<mcd:Version><xsl:value-of select="$rnifVersion"/></mcd:Version>
		</mcd:PackagingProtocol>
		<mcd:MessageId><xsl:value-of select="/MessageControlDocument/TransportInfo/MessageTrackingID"/></mcd:MessageId>
		<mcd:RoutingInfo>
			<mcd:SenderId><xsl:value-of select="/MessageControlDocument/PartnerInfo/SenderInfo/PartnerID"/></mcd:SenderId>
			<mcd:ReceiverId><xsl:value-of select="/MessageControlDocument/PartnerInfo/ReceiverInfo/PartnerID"/></mcd:ReceiverId>
		</mcd:RoutingInfo>
		<mcd:TransportInfo sessionId="{$sessionId}">
			<mcd:MaxRetry><xsl:value-of select="$MaxRetry"/></mcd:MaxRetry>
			<mcd:RetryInterval><xsl:value-of select="$RetryInterval"/></mcd:RetryInterval>
		</mcd:TransportInfo>
		<mcd:TrackingInfo>
			<mcd:CorrelationId><xsl:value-of select="MessageControlDocument/ProcessInfo/PIPInstanceID"/></mcd:CorrelationId>
		</mcd:TrackingInfo>
		<xsl:call-template name="insertStatusInfo"/>
		<xsl:call-template name="insertManifestInfo"/>
	</mcd:MessageControlDocument>
</xsl:template>



<xsl:template name="insertAttachments">	<xsl:choose>
		<xsl:when test="$rnifVersion='2.0'">
			<xsl:for-each select="/MessageControlDocument/ManifestInfo/AttachmentInfo">
				<mcd:MessageContentInfo>
					<mcd:MIMEContentId><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/MIMEContentID"/></mcd:MIMEContentId>
					<mcd:MIMEContentType><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/MIMEContentID"/></mcd:MIMEContentType>
					<mcd:Description><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/Description"/></mcd:Description>
					<mcd:Body bodyEncoding="7-bit"><![CDATA[]]><xsl:value-of select="/MessageControlDocument/ManifestInfo/AttachmentInfo/Body"/><![CDATA[]]></mcd:Body>
				</mcd:MessageContentInfo>
			</xsl:for-each>			
		</xsl:when>
	</xsl:choose></xsl:template></xsl:stylesheet>
<!-- Stylus Studio meta-information - (c)1998-2001 eXcelon Corp.
<metaInformation>
<scenarios ><scenario default="no" name="2.0 RNIF" url="file://c:\Development\SourceIntegrity\rosettanet\test\data\rosettanet\MCD_2A1Test_20.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath=""/><scenario default="yes" name="1.1 RNIF" url="file://c:\Development\SourceIntegrity\rosettanet\test\data\rosettanet\MCD_2A1Test_11.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath=""/></scenarios><MapperInfo  srcSchemaPath="" srcSchemaRoot="" destSchemaPath="" destSchemaRoot="" />
</metaInformation>
-->
